@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -83,13 +83,22 @@ public class SubscriptionJSONParser {
         if (object.has("id")) {
             subscription.setId(object.getInt("id"));
         }
-        subscription.setFolderId(object.getString("folder"));
-        SubscriptionSource source = discovery.getSource(object.getString("source"));
-        subscription.setSource(source);
-        if(source != null) {
-            JSONObject config = object.getJSONObject(subscription.getSource().getId());
-            Map<String, Object> configuration = formParser.parse(config, source.getFormDescription());
-            subscription.setConfiguration(configuration);
+        if(object.has("folder")) {
+            subscription.setFolderId(object.getString("folder"));
+        }
+        if(object.has("enabled")) {
+            subscription.setEnabled(object.getBoolean("enabled"));
+        }
+        if(object.has("source")) {
+            SubscriptionSource source = discovery.getSource(object.getString("source"));
+            subscription.setSource(source);
+            if(source != null) {
+                JSONObject config = object.optJSONObject(subscription.getSource().getId());
+                if(config != null) {
+                    Map<String, Object> configuration = formParser.parse(config, source.getFormDescription());
+                    subscription.setConfiguration(configuration);
+                }
+            }
         }
         return subscription;
     }
