@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,7 @@
 package com.openexchange.subscribe.json;
 
 import java.util.Map;
+import junit.framework.TestCase;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.datatypes.genericonf.DynamicFormDescription;
@@ -57,7 +58,6 @@ import com.openexchange.datatypes.genericonf.FormElement;
 import com.openexchange.subscribe.SimSubscriptionSourceDiscoveryService;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionSource;
-import junit.framework.TestCase;
 
 
 /**
@@ -76,6 +76,7 @@ public class SubscriptionJSONParserTest extends TestCase {
         object = new JSONObject();
         object.put("id", 2);
         object.put("folder" , 12);
+        object.put("enabled", false);
         object.put("source", SOURCE_NAME);
         
         JSONObject config = new JSONObject();
@@ -101,6 +102,7 @@ public class SubscriptionJSONParserTest extends TestCase {
         assertEquals("Got wrong folder", "12", subscription.getFolderId());
         assertNotNull("Got wrong subscription source", subscription.getSource());
         assertEquals("Got wrong subscription source", SOURCE_NAME, subscription.getSource().getId());
+        assertEquals("Got wrong enablement", false, subscription.isEnabled());
         
         Map<String, Object> configuration = subscription.getConfiguration();
     
